pub struct __m128h(/* private fields */);Available on x86-64 only.
128-bit wide set of 8 f16 types, x86-specific
This type is the same as the __m128h type defined by Intel,
representing a 128-bit SIMD register which internally is consisted of
8 packed f16 instances. its purpose is for f16 related intrinsic
implementations.
The in-memory representation of this type is the same as the one of an equivalent array (i.e. the in-memory order of elements is the same, and there is no padding); however, the alignment is different and equal to the size of the type. Note that the ABI for function calls may not be the same.