Struct __m256i Copy item path 1.27.0 · Source pub struct __m256i();Available on x86-64 only.
Expand description 256-bit wide integer vector type, x86-specific
This type is the same as the __m256i type defined by Intel,
representing a 256-bit SIMD register. Usage of this type typically
corresponds to the avx and up target features for x86/x86_64.
Internally this type may be viewed as:
i8x32 - thirty two i8 variables packed together
i16x16 - sixteen i16 variables packed together
i32x8 - eight i32 variables packed together
i64x4 - four i64 variables packed together
(as well as unsigned versions). Each intrinsic may interpret the
internal bits differently, check the documentation of the intrinsic
to see how it’s being used.
The in-memory representation of this type is the same as the one of an
equivalent array (i.e. the in-memory order of elements is the same, and
there is no padding); however, the alignment is different and equal to
the size of the type. Note that the ABI for function calls may not be
the same.
Note that this means that an instance of __m256i typically just means
a “bag of bits” which is left up to interpretation at the point of use.
 Examples
#[cfg(target_arch = "x86" )]
use std::arch::x86::* ;
#[cfg(target_arch = "x86_64" )]
use std::arch::x86_64::* ;
let all_bytes_zero = _mm256_setzero_si256();
let all_bytes_one = _mm256_set1_epi8(1 );
let eight_i32 = _mm256_set_epi32(1 , 2 , 3 , 4 , 5 , 6 , 7 , 8 );1.27.0 · Source  Available on x86 or x86-64 only.
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Performs copy-assignment from
source.
Read more 1.27.0 · Source  Available on x86 or x86-64 only.
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Formats the value using the given formatter.
Read more Source  Available on x86 or x86-64 only.
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Converts to this type from the input type.
Source  Available on x86 or x86-64 only.
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Converts to this type from the input type.
Source  Available on x86 or x86-64 only.
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Converts to this type from the input type.
Source  Available on x86 or x86-64 only.
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Converts to this type from the input type.
Source  Available on x86 or x86-64 only.
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Converts to this type from the input type.
Source  Available on x86 or x86-64 only.
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Converts to this type from the input type.
Source  Available on x86 or x86-64 only.
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Converts to this type from the input type.
Source  Available on x86 or x86-64 only.
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Converts to this type from the input type.
Source  Available on x86 or x86-64 only.
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Converts to this type from the input type.
Source  Available on x86 or x86-64 only.
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Converts to this type from the input type.
Source  Available on x86 or x86-64 only.
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Converts to this type from the input type.
Source  Available on x86 or x86-64 only.
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Converts to this type from the input type.
Source  Available on x86 or x86-64 only.
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Converts to this type from the input type.
Source  Available on x86 or x86-64 only.
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Converts to this type from the input type.
Source  Available on x86 or x86-64 only.
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Converts to this type from the input type.
Source  Available on x86 or x86-64 only.
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Converts to this type from the input type.
1.27.0 · Source  Available on x86 or x86-64 only.
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Immutably borrows from an owned value.
Read more This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit #126799 ) This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Performs copy-assignment from
self to
dest.
Read more This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Returns the argument unchanged.
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The type returned in the event of a conversion error.
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Performs the conversion.
The type returned in the event of a conversion error.
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B) .
Performs the conversion.